summaryrefslogtreecommitdiffstats
path: root/chrome/browser/views/tab_icon_view.h
diff options
context:
space:
mode:
authornsylvain@chromium.org <nsylvain@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-11-18 03:48:01 +0000
committernsylvain@chromium.org <nsylvain@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-11-18 03:48:01 +0000
commit276ae6d3b89a1b521f54277669e73ed8e548fdb1 (patch)
tree2e81baca1aed143c3781409e2cd00aaab6608625 /chrome/browser/views/tab_icon_view.h
parent4c561633e8eab426db0f94f3f03543e94c57ff77 (diff)
downloadchromium_src-276ae6d3b89a1b521f54277669e73ed8e548fdb1.zip
chromium_src-276ae6d3b89a1b521f54277669e73ed8e548fdb1.tar.gz
chromium_src-276ae6d3b89a1b521f54277669e73ed8e548fdb1.tar.bz2
Revert change 5596 because it broke the build
Review URL: http://codereview.chromium.org/11439 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@5598 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/views/tab_icon_view.h')
-rw-r--r--chrome/browser/views/tab_icon_view.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/chrome/browser/views/tab_icon_view.h b/chrome/browser/views/tab_icon_view.h
index 43302228..11b22d4 100644
--- a/chrome/browser/views/tab_icon_view.h
+++ b/chrome/browser/views/tab_icon_view.h
@@ -16,19 +16,19 @@ class TabContents;
////////////////////////////////////////////////////////////////////////////////
class TabIconView : public views::View {
public:
- // Classes implement this interface to provide state for the TabIconView.
- class TabIconViewModel {
+ class TabContentsProvider {
public:
- // Returns true if the TabIconView should show a loading animation.
- virtual bool ShouldTabIconViewAnimate() const = 0;
+ // Should return the current tab contents this TabIconView object is
+ // representing.
+ virtual TabContents* GetCurrentTabContents() = 0;
// Returns the favicon to display in the icon view
- virtual SkBitmap GetFavIconForTabIconView() = 0;
+ virtual SkBitmap GetFavIcon() = 0;
};
static void InitializeIfNeeded();
- explicit TabIconView(TabIconViewModel* provider);
+ explicit TabIconView(TabContentsProvider* provider);
virtual ~TabIconView();
// Invoke whenever the tab state changes or the throbber should update.
@@ -45,8 +45,8 @@ class TabIconView : public views::View {
void PaintThrobber(ChromeCanvas* canvas);
void PaintFavIcon(ChromeCanvas* canvas, const SkBitmap& bitmap);
- // Our model.
- TabIconViewModel* model_;
+ // Our provider of current tab contents.
+ TabContentsProvider* provider_;
// Whether the throbber is running.
bool throbber_running_;